@@ -11,16 +11,18 @@ def gsmn(X, lamb=0.0, method=None, options=None):
         for j in non_adj:
             y = X[:, [j]]
             z = X[:, adj[i]]
-            cmi = conditional_mutual_information(x, y, z, method=None, options=None)
+            cmi = conditional_mutual_information(x, y, z, method=method, options=options)
             if cmi > lamb:
                 adj[i] += [j]
+                adj[j] += [i]
 
         for j in adj[i]:
             other_adj = list(set(adj[i]) - set([j]))
             y = X[:, [j]]
             z = X[:, other_adj]
-            cmi = conditional_mutual_information(x, y, z, method=None, options=None)
+            cmi = conditional_mutual_information(x, y, z, method=method, options=options)
             if cmi < lamb:
                 adj[i].remove(j)
+                adj[j].remove(i)
 
     return adj
